@@ -284,3 +284,6 @@ IDvaluesSpatialPixels <- function(obj) {
 
 length.SpatialPixels = function(x) { nrow(x@coords) }
 length.SpatialGrid = function(x) { .NumberOfCells(x@grid) }
+
+setAs("SpatialGrid", "SpatialPolygons", function(from)
+	as.SpatialPolygons.GridTopology(from@grid))
