@@ -1,4 +1,8 @@
 SpatialLinesDataFrame = function(sl, data, match.ID = TRUE) {
+    if (is.character(match.ID)) {
+        row.names(data) = data[match.ID[1]]
+        match.ID = TRUE
+    }
 	if (match.ID) {
 		Sl_IDs <- sapply(slot(sl, "lines"), function(x) slot(x, "ID"))
 		data_IDs <- row.names(data)
@@ -19,6 +23,11 @@ names.SpatialLinesDataFrame = function(x) names(x@data)
 
 as.data.frame.SpatialLinesDataFrame = function(x, row.names, optional, ...) x@data
 
+setMethod("addAttrToGeom", signature(x = "SpatialLines", y = "data.frame"),
+	function(x, y, match.ID, ...)
+		SpatialLinesDataFrame(x, y, match.ID = match.ID, ...)
+)
+
 setAs("SpatialLinesDataFrame", "data.frame", function(from)
     as.data.frame.SpatialLinesDataFrame(from))
 
@@ -83,3 +92,6 @@ setMethod("split", "SpatialLinesDataFrame", split.data.frame)
 
 print.SpatialLinesDataFrame = function(x, ..., digits = 6, asWKT = .asWKT)
 	print(data.frame(asWKTSpatialLines(x, digits), x@data),...)
+
+setMethod("geometry", "SpatialLinesDataFrame",
+	function(obj) as(obj, "SpatialLines"))
